@@ -81,6 +81,8 @@ pub struct SimpleLogger {
     /// This field is only available if the `timestamps` feature is enabled.
     #[cfg(feature = "timestamps")]
     timestamps: Timestamps,
+    #[cfg(feature = "timestamps")]
+    timestamps_format: Option<&'static [FormatItem<'static>]>,
 
     /// Whether to use color output or not.
     ///
@@ -112,6 +114,9 @@ impl SimpleLogger {
             #[cfg(feature = "timestamps")]
             timestamps: Timestamps::Utc,
 
+            #[cfg(feature = "timestamps")]
+            timestamps_format: None,
+
             #[cfg(feature = "colored")]
             colors: true,
         }
@@ -265,6 +270,28 @@ impl SimpleLogger {
         self
     }
 
+    /// Control the format used for timestamps.
+    ///
+    /// Without this, a default format is used depending on the timestamps type.
+    ///
+    /// The syntax for the format_description macro can be found in the
+    /// [`time` crate book](https://time-rs.github.io/book/api/format-description.html).
+    ///
+    /// ```
+    /// simple_logger::SimpleLogger::new()
+    ///  .with_level(log::LevelFilter::Debug)
+    ///  .env()
+    ///  .with_timestamp_format(time::macros::format_description!("[year]-[month]-[day] [hour]:[minute]:[second]"))
+    ///  .init()
+    ///  .unwrap();
+    /// ```
+    #[must_use = "You must call init() to begin logging"]
+    #[cfg(feature = "timestamps")]
+    pub fn with_timestamp_format(mut self, format: &'static [FormatItem<'static>]) -> SimpleLogger {
+        self.timestamps_format = Some(format);
+        self
+    }
+
     /// Don't display any timestamps.
     ///
     /// This method is only available if the `timestamps` feature is enabled.
@@ -426,15 +453,20 @@ impl Log for SimpleLogger {
                                 "behaviour. See the time crate's documentation for more information. ",
                                 "(https://time-rs.github.io/internal-api/time/index.html#feature-flags)"
                             ))
-                            .format(&TIMESTAMP_FORMAT_OFFSET)
+                            .format(&self.timestamps_format.unwrap_or(TIMESTAMP_FORMAT_OFFSET))
+                            .unwrap()
+                    ),
+                    Timestamps::Utc => format!(
+                        "{} ",
+                        OffsetDateTime::now_utc()
+                            .format(&self.timestamps_format.unwrap_or(TIMESTAMP_FORMAT_UTC))
                             .unwrap()
                     ),
-                    Timestamps::Utc => format!("{} ", OffsetDateTime::now_utc().format(&TIMESTAMP_FORMAT_UTC).unwrap()),
                     Timestamps::UtcOffset(offset) => format!(
                         "{} ",
                         OffsetDateTime::now_utc()
                             .to_offset(offset)
-                            .format(&TIMESTAMP_FORMAT_OFFSET)
+                            .format(&self.timestamps_format.unwrap_or(TIMESTAMP_FORMAT_OFFSET))
                             .unwrap()
                     ),
                 }
@@ -458,9 +490,9 @@ impl Log for SimpleLogger {
 
 #[cfg(all(windows, feature = "colored"))]
 fn set_up_color_terminal() {
-    use atty::Stream;
+    use std::io::{stdout, IsTerminal};
 
-    if atty::is(Stream::Stdout) {
+    if stdout().is_terminal() {
         unsafe {
             use windows_sys::Win32::Foundation::INVALID_HANDLE_VALUE;
             use windows_sys::Win32::System::Console::{
@@ -595,6 +627,15 @@ mod test {
         assert!(builder.timestamps == Timestamps::Local);
     }
 
+    #[test]
+    #[cfg(feature = "timestamps")]
+    #[allow(deprecated)]
+    fn test_with_timestamps_format() {
+        let builder =
+            SimpleLogger::new().with_timestamp_format(time::macros::format_description!("[hour]:[minute]:[second]"));
+        assert!(builder.timestamps_format.is_some());
+    }
+
     #[test]
     #[cfg(feature = "colored")]
     fn test_with_colors() {
